"use strict";
/*
 *   Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 *   Licensed under the Apache License, Version 2.0 (the "License").
 *   You may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
Object.defineProperty(exports, "__esModule", { value: true });
var chai_1 = require("chai");
var fs = require("fs");
var StaticAplTemplateValidator_1 = require("../StaticAplTemplateValidator");
var PackageLoader_1 = require("../util/PackageLoader");
var sinon = require("sinon");
var importInternalTemplate_1 = require("../util/__tests__/template_test_cases/importInternalTemplate");
var configs_1 = require("../configs");
var IValidationInfo_1 = require("../IValidationInfo");
describe('Integration Test to verify the JSON schema.', function () {
    var stub;
    var validator;
    beforeEach(function () {
        validator = new StaticAplTemplateValidator_1.StaticAplTemplateValidator();
        stub = sinon.stub(PackageLoader_1.PackageLoader.prototype, 'load').returns(new Promise(function (resolve) {
            resolve([{
                    json: importInternalTemplate_1.IMPORT_LAYOUT_TEMPLATE_13,
                    justLoaded: true,
                    name: 'alexa-layouts'
                }]);
        }));
    });
    afterEach(function () {
        stub.restore();
    });
    it('should compile with sample templates.', function () { return __awaiter(void 0, void 0, void 0, function () {
        var template, result;
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    template = configs_1.getSampleTemplate(configs_1.SampleTemplateName.IMAGE_RIGHT_DETAIL);
                    return [4 /*yield*/, validator.validate(template.apl)];
                case 1:
                    result = _a.sent();
                    chai_1.expect(result.length).to.be.equal(0);
                    return [2 /*return*/];
            }
        });
    }); });
    it('should received correct amount of validation errors.', function () { return __awaiter(void 0, void 0, void 0, function () {
        var result;
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4 /*yield*/, verifyTemplate('errorTemplate.json')];
                case 1:
                    result = _a.sent();
                    chai_1.expect(result.length).to.be.equal(12);
                    return [2 /*return*/];
            }
        });
    }); });
    it('should compile with video template when souce is array of string.', function () { return __awaiter(void 0, void 0, void 0, function () {
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4 /*yield*/, readSchemaAndPassAllValidations('videoAplTemplateWithArraySource.json')];
                case 1:
                    _a.sent();
                    return [2 /*return*/];
            }
        });
    }); });
    it('should compile with video template when source is string.', function () { return __awaiter(void 0, void 0, void 0, function () {
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4 /*yield*/, readSchemaAndPassAllValidations('videoAplTemplateWithStringSource.json')];
                case 1:
                    _a.sent();
                    return [2 /*return*/];
            }
        });
    }); });
    it('should compile with video template when source is video track object.', function () { return __awaiter(void 0, void 0, void 0, function () {
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4 /*yield*/, readSchemaAndPassAllValidations('videoAplTemplateWithVideoTrackSource.json')];
                case 1:
                    _a.sent();
                    return [2 /*return*/];
            }
        });
    }); });
    it('should compile with video template when source is video track array.', function () { return __awaiter(void 0, void 0, void 0, function () {
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4 /*yield*/, readSchemaAndPassAllValidations('videoAplTemplateWithVideoTrackArraySource.json')];
                case 1:
                    _a.sent();
                    return [2 /*return*/];
            }
        });
    }); });
    it('should compile with video template when source is mixed type.', function () { return __awaiter(void 0, void 0, void 0, function () {
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4 /*yield*/, readSchemaAndPassAllValidations('videoAplTemplateWithMixedSource.json')];
                case 1:
                    _a.sent();
                    return [2 /*return*/];
            }
        });
    }); });
    it('should compile with grid sequence template.', function () { return __awaiter(void 0, void 0, void 0, function () {
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4 /*yield*/, readSchemaAndPassAllValidations('gridSequenceAplTemplate.json')];
                case 1:
                    _a.sent();
                    return [2 /*return*/];
            }
        });
    }); });
    it('should compile with graphic template.', function () { return __awaiter(void 0, void 0, void 0, function () {
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4 /*yield*/, readSchemaAndPassAllValidations('graphicAplTemplate.json')];
                case 1:
                    _a.sent();
                    return [2 /*return*/];
            }
        });
    }); });
    it('should compile with layout template.', function () { return __awaiter(void 0, void 0, void 0, function () {
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4 /*yield*/, readSchemaAndPassAllValidations('layoutAplTemplate.json')];
                case 1:
                    _a.sent();
                    return [2 /*return*/];
            }
        });
    }); });
    it('should compile with resource template.', function () { return __awaiter(void 0, void 0, void 0, function () {
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4 /*yield*/, readSchemaAndPassAllValidations('resourceAplTemplate.json')];
                case 1:
                    _a.sent();
                    return [2 /*return*/];
            }
        });
    }); });
    it('should show correct validation errors with resource template.', function () { return __awaiter(void 0, void 0, void 0, function () {
        var result;
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4 /*yield*/, verifyTemplate('errorResourceAplTemplate.json')];
                case 1:
                    result = _a.sent();
                    chai_1.expect(result).to.have.lengthOf(2);
                    return [2 /*return*/];
            }
        });
    }); });
    it('should compile with graphic template and show errors', function () { return __awaiter(void 0, void 0, void 0, function () {
        var result;
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4 /*yield*/, verifyTemplate('errorGraphicAplTemplate.json')];
                case 1:
                    result = _a.sent();
                    chai_1.expect(result).to.have.lengthOf(2);
                    return [2 /*return*/];
            }
        });
    }); });
    it('should validate multiChildComponent and show warning', function () { return __awaiter(void 0, void 0, void 0, function () {
        var result;
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4 /*yield*/, verifyTemplate('liveDataWarningMultiChildAplTemplate.json')];
                case 1:
                    result = _a.sent();
                    chai_1.expect(result.length).to.be.equal(1);
                    chai_1.expect(result[0].path).to.be.equal('/mainTemplate/item/item/1');
                    chai_1.expect(result[0].level).to.be.equal(IValidationInfo_1.NotificationLevel.WARN);
                    return [2 /*return*/];
            }
        });
    }); });
    it('should validate DataSource', function () { return __awaiter(void 0, void 0, void 0, function () {
        var result;
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4 /*yield*/, validator.validateDataSources({})];
                case 1:
                    result = _a.sent();
                    chai_1.expect(result).to.have.lengthOf(0);
                    return [4 /*yield*/, validator.validateDataSources({ key: 'string' })];
                case 2:
                    result = _a.sent();
                    chai_1.expect(result).to.have.lengthOf(1);
                    return [4 /*yield*/, validator.validateDataSources({ key: false })];
                case 3:
                    result = _a.sent();
                    chai_1.expect(result).to.have.lengthOf(1);
                    return [4 /*yield*/, validator.validateDataSources({ key: null })];
                case 4:
                    result = _a.sent();
                    chai_1.expect(result).to.have.lengthOf(1);
                    return [4 /*yield*/, validator.validateDataSources({ key: [] })];
                case 5:
                    result = _a.sent();
                    chai_1.expect(result).to.have.lengthOf(1);
                    return [4 /*yield*/, validator.validateDataSources({ key: ['string'] })];
                case 6:
                    result = _a.sent();
                    chai_1.expect(result).to.have.lengthOf(1);
                    return [4 /*yield*/, validator.validateDataSources({ key: {} })];
                case 7:
                    result = _a.sent();
                    chai_1.expect(result).to.have.lengthOf(0);
                    return [4 /*yield*/, validator.validateDataSources({ key: { A: 'b' } })];
                case 8:
                    result = _a.sent();
                    chai_1.expect(result).to.have.lengthOf(0);
                    return [2 /*return*/];
            }
        });
    }); });
    it('should validate sources', function () { return __awaiter(void 0, void 0, void 0, function () {
        var result;
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4 /*yield*/, validator.validateSources('')];
                case 1:
                    result = _a.sent();
                    chai_1.expect(result).to.have.lengthOf(1);
                    return [4 /*yield*/, validator.validateSources({})];
                case 2:
                    result = _a.sent();
                    chai_1.expect(result).to.have.lengthOf(0);
                    return [4 /*yield*/, validator.validateSources({ key: 'string' })];
                case 3:
                    result = _a.sent();
                    chai_1.expect(result).to.have.lengthOf(1);
                    return [4 /*yield*/, validator.validateSources({ key: false })];
                case 4:
                    result = _a.sent();
                    chai_1.expect(result).to.have.lengthOf(1);
                    return [4 /*yield*/, validator.validateSources({ key: null })];
                case 5:
                    result = _a.sent();
                    chai_1.expect(result).to.have.lengthOf(1);
                    return [4 /*yield*/, validator.validateSources({ key: [] })];
                case 6:
                    result = _a.sent();
                    chai_1.expect(result).to.have.lengthOf(1);
                    return [4 /*yield*/, validator.validateSources({ key: ['string'] })];
                case 7:
                    result = _a.sent();
                    chai_1.expect(result).to.have.lengthOf(1);
                    return [4 /*yield*/, validator.validateSources({ key: {} })];
                case 8:
                    result = _a.sent();
                    chai_1.expect(result).to.have.lengthOf(0);
                    return [4 /*yield*/, validator.validateSources({ key: { A: 'b' } })];
                case 9:
                    result = _a.sent();
                    chai_1.expect(result).to.have.lengthOf(0);
                    return [4 /*yield*/, validator.validateSources([{ A: 'a' }])];
                case 10:
                    result = _a.sent();
                    chai_1.expect(result).to.have.lengthOf(1);
                    return [2 /*return*/];
            }
        });
    }); });
    function readSchemaAndPassAllValidations(fileName) {
        return __awaiter(this, void 0, void 0, function () {
            var result;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, verifyTemplate(fileName)];
                    case 1:
                        result = _a.sent();
                        chai_1.expect(result).to.have.lengthOf(0);
                        return [2 /*return*/];
                }
            });
        });
    }
    function verifyTemplate(fileName) {
        var data = fs.readFileSync("src/__tests__/templates/" + fileName, 'utf8');
        return validator.validate(JSON.parse(data));
    }
});
//# sourceMappingURL=StaticAplTemplateValidator.spec.js.map