/*
 *   Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 *   Licensed under the Apache License, Version 2.0 (the "License").
 *   You may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 */
/* tslint:disable */
'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
exports.Source = exports.UrlWithHeaders = exports.Url = exports.Action = exports.ActionArray = exports.Role = void 0;
exports.Role = {
    "type": "string",
    "description": "Role or purpose of the component.",
    "enum": [
        "adjustable",
        "alert",
        "button",
        "checkbox",
        "combobox",
        "header",
        "image",
        "imagebutton",
        "keyboardkey",
        "link",
        "list",
        "listitem",
        "menu",
        "menubar",
        "menuitem",
        "progressbar",
        "radio",
        "radiogroup",
        "scrollbar",
        "search",
        "spinbutton",
        "summary",
        "switch",
        "tab",
        "tablist",
        "text",
        "timer",
        "toolbar"
    ]
};
exports.ActionArray = {
    "type": "array",
    "items": {
        "$ref": "#/definitions/Action"
    }
};
exports.Action = {
    "properties": {
        "command": {
            "$ref": "#/definitions/Command",
            "description": "A command to execute when this action is triggered"
        },
        "commands": {
            "$ref": "#/definitions/CommandArray",
            "description": "An array of commands to execute when this action is triggered"
        },
        "enabled": {
            "type": "boolean",
            "description": "If true this action can be executed by the user"
        },
        "label": {
            "type": "string",
            "description": "A localized description of this action for presentation to the user"
        },
        "name": {
            "type": "string",
            "description": "The name of the action to perform"
        }
    },
    "additionalProperties": false,
    "required": [
        "label",
        "name"
    ]
};
// only do very relax validation on url string by default
exports.Url = {
    "type": "string"
};
exports.UrlWithHeaders = {
    "type": "object",
    "properties": {
        "url": exports.Url,
        "headers": {
            "$ref": "#/definitions/stringArray"
        },
        "description": {
            "type": "string"
        },
    },
    "required": ["url"],
    "additionalProperty": false
};
exports.Source = {
    "oneOf": [
        exports.Url,
        exports.UrlWithHeaders,
        {
            "type": "array",
            "items": {
                "oneOf": [exports.Url, exports.UrlWithHeaders]
            }
        }
    ]
};
//# sourceMappingURL=CommonDefinition.js.map